@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -68,11 +68,11 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
     protected final Object[][] getContents() {
         final String[] GMT = new String[] {
                "Greenwich Mean Time",
+               "GMT",
                "",
+               "GMT",
                "",
-               "",
-               "",
-               "",
+               "GMT",
             };
         final String[] Acre = new String[] {
                "Acre-standerttiid",
@@ -92,11 +92,11 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             };
         final String[] Cuba = new String[] {
                "Kubaanske standerttiid",
-               "",
+               "CST",
                "Kubaanske simmertiid",
-               "",
+               "CDT",
                "Kubaanske tiid",
-               "",
+               "CT",
             };
         final String[] Fiji = new String[] {
                "Fijyske standerttiid",
@@ -180,11 +180,11 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             };
         final String[] China = new String[] {
                "Sineeske standerttiid",
-               "",
+               "CST",
                "Sineeske simmertiid",
-               "",
+               "CDT",
                "Sineeske tiid",
-               "",
+               "CT",
             };
         final String[] Cocos = new String[] {
                "Kokoseil\u00e2nske tiid",
@@ -212,19 +212,19 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             };
         final String[] Japan = new String[] {
                "Japanske standerttiid",
-               "",
+               "JST",
                "Japanske simmertiid",
-               "",
+               "JDT",
                "Japanske tiid",
-               "",
+               "JT",
             };
         final String[] Korea = new String[] {
                "Koreaanske standerttiid",
-               "",
+               "KST",
                "Koreaanske simmertiid",
-               "",
+               "KST",
                "Koreaanske tiid",
-               "",
+               "KST",
             };
         final String[] Nauru = new String[] {
                "Nauruaanske tiid",
@@ -252,11 +252,11 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             };
         final String[] Samoa = new String[] {
                "Samoaanske standerttiid",
-               "",
+               "SST",
                "Samoaanske simmertiid",
-               "",
+               "SST",
                "Samoaanske tiid",
-               "",
+               "SST",
             };
         final String[] Syowa = new String[] {
                "Syowa tiid",
@@ -276,11 +276,11 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             };
         final String[] Alaska = new String[] {
                "Alaska-standerttiid",
-               "",
+               "AKST",
                "Alaska-simmertiid",
-               "",
+               "AKDT",
                "Alaska-tiid",
-               "",
+               "AKT",
             };
         final String[] Amazon = new String[] {
                "Amazone-standerttiid",
@@ -340,11 +340,11 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             };
         final String[] Israel = new String[] {
                "Isra\u00eblyske standerttiid",
-               "",
+               "IST",
                "Isra\u00eblyske simmertiid",
-               "",
+               "IDT",
                "Isra\u00eblyske tiid",
-               "",
+               "IT",
             };
         final String[] Kosrae = new String[] {
                "Kosraese tiid",
@@ -364,11 +364,11 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             };
         final String[] Moscow = new String[] {
                "Moskou-standerttiid",
-               "",
+               "MSK",
                "Moskou-simmertiid",
-               "",
+               "MSK",
                "Moskou-tiid",
-               "",
+               "MSK",
             };
         final String[] Ponape = new String[] {
                "Pohnpei tiid",
@@ -396,11 +396,11 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             };
         final String[] Taipei = new String[] {
                "Taipei standerttiid",
-               "",
+               "CST",
                "Taipei simmertiid",
-               "",
+               "CDT",
                "Taipei tiid",
-               "",
+               "CT",
             };
         final String[] Tuvalu = new String[] {
                "Tuvaluaanske tiid",
@@ -580,11 +580,11 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             };
         final String[] Atlantic = new String[] {
                "Atlantic-standerttiid",
-               "",
+               "AST",
                "Atlantic-simmertiid",
-               "",
+               "ADT",
                "Atlantic-tiid",
-               "",
+               "AT",
             };
         final String[] Brasilia = new String[] {
                "Brazyljaanske standerttiid",
@@ -596,11 +596,11 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             };
         final String[] Chamorro = new String[] {
                "Chamorro-tiid",
+               "ChST",
                "",
+               "ChST",
                "",
-               "",
-               "",
-               "",
+               "ChST",
             };
         final String[] Colombia = new String[] {
                "Kolombiaanske standerttiid",
@@ -644,11 +644,11 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             };
         final String[] Pakistan = new String[] {
                "Pakistaanske standerttiid",
-               "",
+               "PKT",
                "Pakistaanske simmertiid",
-               "",
+               "PKST",
                "Pakistaanske tiid",
-               "",
+               "PKT",
             };
         final String[] Paraguay = new String[] {
                "Paraguayaanske standerttiid",
@@ -708,11 +708,11 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             };
         final String[] Hong_Kong = new String[] {
                "Hongkongse standerttiid",
-               "",
+               "HKT",
                "Hongkongse simmertiid",
-               "",
+               "HKST",
                "Hongkongse tiid",
-               "",
+               "HKT",
             };
         final String[] Indochina = new String[] {
                "Yndochinese tiid",
@@ -780,11 +780,11 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             };
         final String[] Volgograd = new String[] {
                "Wolgograd-standerttiid",
-               "",
+               "MSK",
                "Wolgograd-simmertiid",
-               "",
+               "MSK",
                "Wolgograd-tiid",
-               "",
+               "MSK",
             };
         final String[] Azerbaijan = new String[] {
                "Azerbeidzjaanske standerttiid",
@@ -868,11 +868,11 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             };
         final String[] New_Zealand = new String[] {
                "Nij-Seel\u00e2nske standerttiid",
-               "",
+               "NZST",
                "Nij-Seel\u00e2nske simmertiid",
-               "",
+               "NZDT",
                "Nij-Seel\u00e2nske tiid",
-               "",
+               "NZT",
             };
         final String[] Novosibirsk = new String[] {
                "Novosibirsk-standerttiid",
@@ -884,11 +884,11 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             };
         final String[] Philippines = new String[] {
                "Filipijnse standerttiid",
-               "",
+               "PST",
                "Filipijnse simmertiid",
-               "",
+               "PDT",
                "Filipijnse tiid",
-               "",
+               "PT",
             };
         final String[] Vladivostok = new String[] {
                "Vladivostok-standerttiid",
@@ -916,11 +916,11 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             };
         final String[] Newfoundland = new String[] {
                "Newfoundl\u00e2nske-standerttiid",
-               "",
+               "NST",
                "Newfoundl\u00e2nske-simmertiid",
-               "",
+               "NDT",
                "Newfoundl\u00e2nske-tiid",
-               "",
+               "NT",
             };
         final String[] Turkmenistan = new String[] {
                "Turkmeense standerttiid",
@@ -964,27 +964,27 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "Sintraal-Afrikaanske tiid",
+               "CAT",
                "",
+               "CAT",
                "",
-               "",
-               "",
-               "",
+               "CAT",
             };
         final String[] Africa_Eastern = new String[] {
                "East-Afrikaanske tiid",
+               "EAT",
                "",
+               "EAT",
                "",
-               "",
-               "",
-               "",
+               "EAT",
             };
         final String[] Africa_Western = new String[] {
                "West-Afrikaanske standerttiid",
-               "",
+               "WAT",
                "West-Afrikaanske simmertiid",
-               "",
+               "WAT",
                "West-Afrikaanske tiid",
-               "",
+               "WAT",
             };
         final String[] DumontDUrville = new String[] {
                "Dumont-d\u2019Urville tiid",
@@ -1020,35 +1020,35 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             };
         final String[] Africa_Southern = new String[] {
                "S\u00fbd-Afrikaanske tiid",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] America_Central = new String[] {
                "Central-standerttiid",
-               "",
+               "CST",
                "Central-simmertiid",
-               "",
+               "CDT",
                "Central-tiid",
-               "",
+               "CT",
             };
         final String[] America_Eastern = new String[] {
                "Eastern-standerttiid",
-               "",
+               "EST",
                "Eastern-simmertiid",
-               "",
+               "EST",
                "Eastern-tiid",
-               "",
+               "EST",
             };
         final String[] America_Pacific = new String[] {
                "Pasifik-standerttiid",
-               "",
+               "PST",
                "Pasifik-simmertiid",
-               "",
+               "PDT",
                "Pasifik-tiid",
-               "",
+               "PT",
             };
         final String[] French_Southern = new String[] {
                "Fr\u00e2nske S\u00fadlike en Antarctyske tiid",
@@ -1068,11 +1068,11 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             };
         final String[] Hawaii_Aleutian = new String[] {
                "Hawaii-Aleoetyske standerttiid",
-               "",
+               "HST",
                "Hawaii-Aleoetyske simmertiid",
-               "",
+               "HST",
                "Hawaii-Aleoetyske tiid",
-               "",
+               "HST",
             };
         final String[] Phoenix_Islands = new String[] {
                "Phoenixeil\u00e2nske tiid",
@@ -1092,11 +1092,11 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             };
         final String[] America_Mountain = new String[] {
                "Mountain-standerttiid",
-               "",
+               "MST",
                "Mountain-simmertiid",
-               "",
+               "MST",
                "Mountain-tiid",
-               "",
+               "MST",
             };
         final String[] Marshall_Islands = new String[] {
                "Marshalleil\u00e2nske tiid",
@@ -1116,27 +1116,27 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             };
         final String[] Australia_Central = new String[] {
                "Midden-Australyske standerttiid",
-               "",
+               "ACST",
                "Midden-Australyske simmertiid",
-               "",
+               "ACDT",
                "Midden-Australyske tiid",
-               "",
+               "ACT",
             };
         final String[] Australia_Eastern = new String[] {
                "East-Australyske standerttiid",
-               "",
+               "AEST",
                "East-Australyske simmertiid",
-               "",
+               "AEDT",
                "East-Australyske tiid",
-               "",
+               "AET",
             };
         final String[] Australia_Western = new String[] {
                "West-Australyske standerttiid",
-               "",
+               "AWST",
                "West-Australyske simmertiid",
-               "",
+               "AWDT",
                "West-Australyske tiid",
-               "",
+               "AWT",
             };
         final String[] Greenland_Eastern = new String[] {
                "East-Groenl\u00e2nske standerttiid",
@@ -1156,27 +1156,27 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             };
         final String[] Indonesia_Central = new String[] {
                "Sintraal-Yndonezyske tiid",
+               "WITA",
                "",
+               "WITA",
                "",
-               "",
-               "",
-               "",
+               "WITA",
             };
         final String[] Indonesia_Eastern = new String[] {
                "East-Yndonezyske tiid",
+               "WIT",
                "",
+               "WIT",
                "",
-               "",
-               "",
-               "",
+               "WIT",
             };
         final String[] Indonesia_Western = new String[] {
                "West-Yndonezyske tiid",
+               "WIB",
                "",
+               "WIB",
                "",
-               "",
-               "",
-               "",
+               "WIB",
             };
         final String[] Kazakhstan_Eastern = new String[] {
                "East-Kazachse tiid",
@@ -1253,7 +1253,6 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1348,7 +1347,6 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1363,11 +1361,11 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "Europe/Dublin",
                 new String[] {
                     "Greenwich Mean Time",
-                    "",
+                    "GMT",
                     "Ierse simmertiid",
+                    "IST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Jersey", GMT },
@@ -1375,11 +1373,11 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "Europe/London",
                 new String[] {
                     "Greenwich Mean Time",
-                    "",
+                    "GMT",
                     "Britse simmertiid",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Madrid", Europe_Central },
@@ -1436,11 +1434,11 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "Europe/Belfast",
                 new String[] {
                     "Greenwich Mean Time",
-                    "",
+                    "GMT",
                     "Britse simmertiid",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Tallinn", Europe_Eastern },
@@ -1486,7 +1484,7 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -1570,6 +1568,7 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "America/Araguaina", Brasilia },
             { "America/Boa_Vista", Amazon },
             { "America/Catamarca", Argentina },
+            { "America/Chihuahua", America_Central },
             { "America/Fortaleza", Brasilia },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -1654,6 +1653,7 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -1726,18 +1726,15 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "timezone.excity.America/Bogota", "Bogot\u00e1" },
             { "timezone.excity.America/Cuiaba", "Cuiab\u00e1" },
             { "timezone.excity.America/Maceio", "Macei\u00f3" },
-            { "timezone.excity.America/Merida", "M\u00e9rida" },
             { "timezone.excity.Asia/Hong_Kong", "Hongkong" },
             { "timezone.excity.Asia/Jerusalem", "Jeruzalem" },
             { "timezone.excity.Asia/Kamchatka", "Kamtsjatka" },
             { "timezone.excity.Europe/Vatican", "Fatikaanst\u00ead" },
-            { "timezone.excity.Indian/Reunion", "R\u00e9union" },
             { "timezone.excity.Pacific/Easter", "Peaskeeil\u00e2n" },
             { "timezone.excity.Pacific/Noumea", "Noum\u00e9a" },
             { "timezone.excity.Africa/Khartoum", "Khartoem" },
             { "timezone.excity.Africa/Sao_Tome", "Sao Tom\u00e9" },
             { "timezone.excity.America/Cordoba", "C\u00f3rdoba" },
-            { "timezone.excity.America/Curacao", "Cura\u00e7ao" },
             { "timezone.excity.Asia/Phnom_Penh", "Phnom-Penh" },
             { "timezone.excity.Atlantic/Azores", "Azoren" },
             { "timezone.excity.Atlantic/Canary", "Kanaryske Eilannen" },
@@ -1749,7 +1746,6 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Uzhgorod", "Oezjhorod" },
             { "timezone.excity.Indian/Maldives", "Maldiven" },
             { "timezone.excity.Pacific/Gambier", "Gambiereilannen" },
-            { "timezone.excity.America/Asuncion", "Asunci\u00f3n" },
             { "timezone.excity.America/Mazatlan", "Mazatl\u00e1n" },
             { "timezone.excity.Asia/Krasnoyarsk", "Krasnojarsk" },
             { "timezone.excity.Europe/Bucharest", "Boekarest" },
@@ -1771,7 +1767,6 @@ public class TimeZoneNames_fy extends TimeZoneNamesBundle {
             { "timezone.excity.Atlantic/Cape_Verde", "Kaapverdi\u00eb" },
             { "timezone.excity.America/Lower_Princes", "Beneden Prinsen Kwartier" },
             { "timezone.excity.America/St_Barthelemy", "Saint-Barth\u00e9lemy" },
-            { "timezone.excity.America/Bahia_Banderas", "Bah\u00eda de Banderas" },
             { "timezone.excity.Atlantic/South_Georgia", "S\u00fbd-Georgia" },
             { "timezone.excity.America/Argentina/Tucuman", "Tucum\u00e1n" },
             { "timezone.excity.America/North_Dakota/Beulah", "Beulah, Noard-Dakota" },
